<?php
/** Wu (吴语)
 *
 * @ingroup Language
 * @file
 *
 * @author Hercule
 * @author O
 */

$fallback = 'zh-hans';

$messages = array(
# User preference toggles
'tog-highlightbroken'         => '呒效链接格式<a href="" class="new">像该样</a>（或者像该个<a href="" class="internal">？</a>）',
'tog-hideminor'               => '勒拉近段辰光个改动里向囥脱小改动',
'tog-extendwatchlist'         => '扩展监控列表来显示亨白浪当个好应用个改动',
'tog-usenewrc'                => '强化版近段辰光个改动（JavaScript）',
'tog-showtoolbar'             => '显示编辑工具条（JavaScript）',
'tog-editondblclick'          => '双击时编辑页面（JavaScript）',
'tog-editsectiononrightclick' => '允许右击标题编辑段落（JavaScript）',
'tog-showtoc'                 => '显示目录（针对一页超过三个标题个页面）',
'tog-rememberpassword'        => '登该台电脑浪记牢我个登录',
'tog-watchcreations'          => '将我创建个页面添加到我个监控列表',
'tog-watchdefault'            => '将我编辑个页面添加到我个监控列表',
'tog-watchmoves'              => '将我移动个页面添加到我个监控列表',
'tog-watchdeletion'           => '将我删除个页面添加到我个监控列表',
'tog-enotifusertalkpages'     => '在我个讲张更改时发邮件通知我',
'tog-enotifrevealaddr'        => '在通邮件知列表中显示我个邮件地址',
'tog-shownumberswatching'     => '显示监控此页个用户数',
'tog-fancysig'                => '原始签名（没有自动链接）',
'tog-showjumplinks'           => '启用“转到”访问链接',
'tog-uselivepreview'          => '使用实时预览（Javascript）（试验中）',
'tog-watchlisthideown'        => '勒拉监控列表里向囥脱我个编辑',
'tog-watchlisthidebots'       => '勒拉监控列表里向囥脱机器人个编辑',
'tog-watchlisthideminor'      => '在监控列表中隐藏微小更改',
'tog-showhiddencats'          => '显示囥脱分类',

'underline-always'  => '总归',
'underline-never'   => '从来弗',
'underline-default' => '浏览器默认',

'skinpreview' => '(预览)',

# Dates
'sunday'        => '星期天',
'monday'        => '星期一',
'tuesday'       => '星期二',
'wednesday'     => '星期三',
'thursday'      => '星期四',
'friday'        => '星期五',
'saturday'      => '星期六',
'sun'           => '日',
'mon'           => '一',
'tue'           => '二',
'wed'           => '三',
'thu'           => '四',
'fri'           => '五',
'sat'           => '六',
'january'       => '1月',
'february'      => '2月',
'march'         => '3月',
'april'         => '4月',
'may_long'      => '5月',
'june'          => '6月',
'july'          => '7月',
'august'        => '8月',
'september'     => '9月',
'october'       => '10月',
'november'      => '11月',
'december'      => '12月',
'january-gen'   => '一月',
'february-gen'  => '二月',
'march-gen'     => '三月',
'april-gen'     => '四月',
'may-gen'       => '五月',
'june-gen'      => '六月',
'july-gen'      => '七月',
'august-gen'    => '八月',
'september-gen' => '九月',
'october-gen'   => '十月',
'november-gen'  => '十一月',
'december-gen'  => '十二月',
'jan'           => '1月',
'feb'           => '2月',
'mar'           => '3月',
'apr'           => '4月',
'may'           => '5月',
'jun'           => '6月',
'jul'           => '7月',
'aug'           => '8月',
'sep'           => '9月',
'oct'           => '10月',
'nov'           => '11月',
'dec'           => '12月',

# Categories related messages
'pagecategories'                => '个分类',
'category_header'               => '“$1”分类中个页面',
'subcategories'                 => '亚类',
'category-media-header'         => '"$1"分类中个媒体',
'category-empty'                => "''该个分类中尚未包含任何文章或媒体。''",
'hidden-categories'             => '$1隐藏分类',
'hidden-category-category'      => '囥脱分类', # Name of the category where hidden categories will be listed
'category-subcat-count-limited' => '该个分类中有个亚类。',

'mainpagetext'      => "<big>'''已成功安装MediaWiki！'''</big>",
'mainpagedocfooter' => '请访问[http://meta.wikimedia.org/wiki/Help:Contents 用户手册]以获得使用此维基软件的信息！

== 入门 ==
* [http://www.mediawiki.org/wiki/Manual:Configuration_settings MediaWiki 配置设置列表]
* [http://www.mediawiki.org/wiki/Manual:FAQ MediaWiki 常见问题解答]
* [https://lists.wikimedia.org/mailman/listinfo/mediawiki-announce MediaWiki 发布邮件列表]',

'about'          => '关于',
'article'        => '文章',
'newwindow'      => '(在新窗口中打开)',
'cancel'         => '取消',
'qbfind'         => '查找',
'qbedit'         => '编辑',
'qbpageoptions'  => '页面选项',
'qbmyoptions'    => '我个选项',
'qbspecialpages' => '特殊页面',
'moredotdotdot'  => '还有...',
'mypage'         => '我个页面',
'mytalk'         => '我个讲张',
'anontalk'       => '该IP个讲张',
'navigation'     => '导航',
'and'            => '搭仔',

'errorpagetitle'    => '错误',
'returnto'          => '返回到$1。',
'tagline'           => '来自{{SITENAME}}',
'help'              => '帮助',
'search'            => '搜寻',
'searchbutton'      => '搜寻',
'go'                => '进入',
'searcharticle'     => '进入',
'history'           => '页面历史',
'history_short'     => '历史',
'info_short'        => '信息',
'printableversion'  => '好打印个版本',
'permalink'         => '永久链接',
'print'             => '打印',
'edit'              => '编辑',
'editthispage'      => '编辑此页',
'delete'            => '删除',
'deletethispage'    => '删除此页',
'undelete_short'    => '反删除项修订',
'protect'           => '保护',
'protect_change'    => '更改保护',
'protectthispage'   => '保护此页',
'unprotect'         => '解除保护',
'unprotectthispage' => '解除此页保护',
'newpage'           => '新建页面',
'talkpage'          => '讨论此页',
'talkpagelinktext'  => '讲张',
'specialpage'       => '特殊页面',
'personaltools'     => '个人工具',
'postcomment'       => '发表评论',
'articlepage'       => '查看内容页面',
'talk'              => '讨论',
'views'             => '查看',
'toolbox'           => '家生',
'userpage'          => '查看用户页面',
'projectpage'       => '查看计划页面',
'imagepage'         => '查看文物页面',
'mediawikipage'     => '查看信息页面',
'templatepage'      => '查看模板页面',
'viewhelppage'      => '查看帮忙页',
'categorypage'      => '查看分类页面',
'viewtalkpage'      => '查看讨论页',
'otherlanguages'    => '别样闲话版本',
'redirectedfrom'    => '（重定向自$1）',
'redirectpagesub'   => '重定向页面',
'protectedpage'     => '拨保护个页面',
'jumpto'            => '跳到：',
'jumptonavigation'  => '导航',
'jumptosearch'      => '搜寻',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '关于{{SITENAME}}',
'aboutpage'            => 'Project:关于',
'copyright'            => '内容侪拉$1下底发布。',
'copyrightpage'        => '{{ns:project}}:版权',
'currentevents'        => '近段辰光个事体',
'currentevents-url'    => 'Project:近段辰光个事体',
'disclaimers'          => '免责声明',
'disclaimerpage'       => 'Project:免责声明',
'edithelp'             => '编辑帮助',
'edithelppage'         => 'Help:如何编辑页面',
'helppage'             => 'Help:目录',
'mainpage'             => '封面',
'mainpage-description' => '封面',
'portal'               => '社区门荡',
'portal-url'           => 'Project:社区门荡',
'privacy'              => '隐私政策',
'privacypage'          => 'Project:隐私政策',

'ok'                      => '确定',
'retrievedfrom'           => '取自“$1”',
'youhavenewmessages'      => '侬有$1（$2）。',
'newmessageslink'         => '新信息',
'newmessagesdifflink'     => '上次更改',
'youhavenewmessagesmulti' => '侬有新信息在$1',
'editsection'             => '编辑',
'editold'                 => '编辑',
'editsectionhint'         => '编辑段落: $1',
'toc'                     => '目录',
'showtoc'                 => '显示',
'hidetoc'                 => '囥脱',
'thisisdeleted'           => '查看或者恢复$1？',
'viewdeleted'             => '望望$1看？',
'restorelink'             => '个被删除个版本',
'site-rss-feed'           => '$1的RSS订阅',
'site-atom-feed'          => '$1的Atom订阅',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => '文章',
'nstab-user'      => '用户页面',
'nstab-media'     => '媒体页面',
'nstab-special'   => '特殊页面',
'nstab-project'   => '项目页面',
'nstab-image'     => '文物',
'nstab-mediawiki' => '信息',
'nstab-template'  => '模板',
'nstab-help'      => '帮助页面',
'nstab-category'  => '分类',

# Main script and global functions
'nosuchaction'      => '呒拨实梗个操作',
'nosuchspecialpage' => '呒拨实梗个特殊页面',

# General errors
'error'           => '错误',
'laggedslavemode' => '警告: 页面可能弗包含最近个更新。',
'filedeleteerror' => '呒能删除文物“$1”。',
'filenotfound'    => '寻弗着文件 "$1"。',
'badtitle'        => '该只标题弗来三',
'viewsource'      => '源码',
'viewsourcefor'   => '$1个源码',
'actionthrottled' => '动作已压制',

# Login and logout pages
'logouttitle'                => '用户登出',
'logouttext'                 => "'''倷已经登出哉。'''<br /> 倷可以继续匿名使用{{SITENAME}} ，倷也可以再次以相同或者两样个用户名登录。注意，有星页面作兴还是会搭倷登出前头一样显示，一脚到倷清脱倷个浏览器缓存。",
'welcomecreation'            => '== 欢迎， $1！ ==

倷个户头已经建立哉。覅忘记脱改动倷个{{SITENAME}}偏好噢。',
'loginpagetitle'             => '用户登录',
'yourname'                   => '用户名:',
'yourpassword'               => '密码:',
'yourpasswordagain'          => '再打一遍密码:',
'remembermypassword'         => '登该台电脑浪记牢我个登录',
'login'                      => '登录',
'loginprompt'                => '定规要启用仔缓存(cookies)倷再好登录到{{SITENAME}}。',
'userlogin'                  => '登录 / 新开户头',
'logout'                     => '登出',
'userlogout'                 => '登出',
'notloggedin'                => '朆登录',
'nologin'                    => '您还没有账户吗？$1。',
'nologinlink'                => '新开户头',
'createaccount'              => '新开户头',
'gotaccount'                 => '已经有仔帐号哉？ $1。',
'gotaccountlink'             => '登录',
'badretype'                  => '倷输入个密码搭倪个档案弗配。',
'userexists'                 => '输入个用户名已经拨人注脱哉。请再选个两样个用户名。',
'youremail'                  => '电子邮件:',
'username'                   => '用户名:',
'uid'                        => '用户号：',
'yourrealname'               => '真实姓名:',
'yourlanguage'               => '语言:',
'yournick'                   => '绰号:',
'badsig'                     => '无效原始签名；检查 HTML 标签。',
'email'                      => '电子邮件',
'loginerror'                 => '登录错误',
'prefs-help-email'           => '电子邮箱是备选的，让别人家好通过倷个用户页或者用户讲张页面联系着倷，用弗着暴露倷个身份。',
'loginsuccesstitle'          => '登录成功',
'loginsuccess'               => "'''倷现在以 \"\$1\" 个身份登录到{{SITENAME}}。 '''",
'nouserspecified'            => '侬必须选个用户名。',
'wrongpassword'              => '密码弗对嗄。请倷再试试看。',
'mailmypassword'             => '将新密码寄给我',
'acct_creation_throttle_hit' => '对覅起，侬经建了$1个账号。侬呒能再建了。',
'emailauthenticated'         => '倷个电子邮箱地址勒拉 $1 验证过哉。',
'accountcreated'             => '户头开好哉',
'accountcreatedtext'         => '$1 个户头已经建立哉。',
'loginlanguagelabel'         => '语言：$1',

# Edit page toolbar
'bold_sample'    => '黑体文本',
'bold_tip'       => '黑体文本',
'italic_sample'  => '斜体文字',
'italic_tip'     => '斜体文字',
'link_sample'    => '链接标题',
'link_tip'       => '内部链接',
'extlink_sample' => 'http://www.example.com 链接标题',
'headline_tip'   => '2级标题文字',
'math_sample'    => '往该里加数学公式',
'image_tip'      => '嵌入图片',
'sig_tip'        => '倷个签名搭仔辰光记录',

# Edit pages
'summary'            => '总结',
'minoredit'          => '该个是个小改动',
'watchthis'          => '监控该只页面',
'savearticle'        => '保存页面',
'preview'            => '预览',
'showpreview'        => '显示预览',
'showdiff'           => '显示改动',
'anoneditwarning'    => "'''警告：''' 倷朆登录。倷个IP地址会拨记录勒该页面个编辑历史里向。",
'blockednoreason'    => '无给出原因',
'whitelistedittext'  => '侬必须$1才能编辑。',
'loginreqtitle'      => '必须登录',
'loginreqlink'       => '登录',
'accmailtitle'       => '密码已发送哉。',
'accmailtext'        => '"$1"个密码已经发送到 $2 哉。',
'newarticle'         => '(新)',
'newarticletext'     => "倷跟仔链接来着一个还弗勒里个页面。
要创建该页面呢，就勒下底个框框里向开始写（[[{{MediaWiki:Helppage}}|帮助页面]]浪有更加多个信息）。
要是倷是弗用心到该搭个说话，只要点击倷浏览器个'''返回'''揿钮。",
'noarticletext'      => '个篇文章目前还呒拨内容，倷可以拉别个页面里向[[Special:Search/{{PAGENAME}}|寻寻该只标题看]]或者[{{fullurl:{{FULLPAGENAME}}|action=edit}} 编辑当前页面].',
'note'               => "'''注意：'''",
'previewnote'        => "'''该个还只是预览；改动还朆保存！'''",
'editing'            => '正在编辑$1',
'editingsection'     => '正在编辑$1（段落）',
'editingcomment'     => '正在编辑$1（评论）',
'editconflict'       => '编辑冲突: $1',
'yourtext'           => '侬个文字',
'editingold'         => "''' 注意：倷勒里改动一只已经过期个页面修改。 如果倷保存俚个说话，勒拉该个修改之后个亨白浪当个修改侪会呒拨个。'''",
'template-protected' => '(保护)',

# Account creation failure
'cantcreateaccounttitle' => '呒处建立帐户',

# History pages
'viewpagelogs' => '查看该页面日志',
'nohistory'    => '该只页面呒拨编辑历史。',
'nextrevision' => '新点个版本→',
'cur'          => '当前',
'last'         => '上个',
'histlegend'   => '选择比较版本：标记要比较个两只版本，回车或者揿页面底里个揿钮。<br /> 图例：(当前) = 搭当前版本有啥两样， (上个) = 搭上个版本有啥两样，小 = 小改动。',
'deletedrev'   => '[已删]',
'histfirst'    => '顶早',
'histlast'     => '顶晏',
'historyempty' => '（空）',

# Revision feed
'history-feed-title' => '校订历史',

# Revision deletion
'rev-delundel' => '显示/囥脱',

# Diffs
'compareselectedversions' => '比较选中个版本',
'editundo'                => '撤销',
'diff-multi'              => '($1个中途个修订版本无没显示。)',

# Search results
'searchresults'         => '搜索结果',
'searchresulttext'      => '更加全面个关于拉{{SITENAME}}里向搜索个信息，请倷看[[{{MediaWiki:Helppage}}:搜索|搜索{{SITENAME}}]]。',
'searchsubtitle'        => "倷搜寻 '''[[:$1]]'''",
'searchsubtitleinvalid' => "倷搜寻 '''$1'''",
'noexactmatch'          => "''呒拨叫\"\$1\"个页面啘。''' 倷可以[[:\$1|建立俚]]。",
'prevn'                 => '上个 $1',
'nextn'                 => '下个 $1',
'viewprevnext'          => '查看 ($1) ($2) ($3)',
'powersearch'           => '高级搜索',

# Preferences page
'preferences'           => '偏好',
'mypreferences'         => '我个所欢喜',
'prefsnologin'          => '朆登录',
'qbsettings-none'       => '呒',
'changepassword'        => '改密码',
'skin'                  => '皮肤',
'math'                  => '数学公式',
'datedefault'           => '呒拨偏好',
'datetime'              => '日脚搭仔辰光',
'prefs-personal'        => '用户档案',
'prefs-rc'              => '近段辰光个改动',
'prefs-watchlist'       => '监控列表',
'prefs-watchlist-days'  => '勒拉监控列表里向显示个日数：',
'prefs-watchlist-edits' => '勒拉扩展个监控列表里向显示个编辑趟数：',
'saveprefs'             => '保存',
'oldpassword'           => '旧密码:',
'newpassword'           => '新密码:',
'retypenew'             => '再打一遍新密码:',
'textboxsize'           => '编辑',
'searchresultshead'     => '搜索',
'recentchangescount'    => '近段辰光个改动标题数：',
'savedprefs'            => '倷个偏好已经保存哉。',
'timezonelegend'        => '时区',
'localtime'             => '当地辰光',
'servertime'            => '服务器辰光',
'allowemail'            => '接受别个用户个电子邮件',
'default'               => '默认',
'files'                 => '文件',

# User rights
'userrights-user-editname' => '输入用户名:',

# Groups
'group-bot'        => '机器人',
'group-sysop'      => '管理员',
'group-bureaucrat' => '行政员',
'group-all'        => '（全）',

'group-bot-member'        => '机器人',
'group-sysop-member'      => '管理员',
'group-bureaucrat-member' => '行政员',

'grouppage-bot'        => '{{ns:project}}:机器人',
'grouppage-sysop'      => '{{ns:project}}:管理员',
'grouppage-bureaucrat' => '{{ns:project}}:行政员',

# User rights log
'rightsnone' => '（呒）',

# Recent changes
'recentchanges'     => '近段辰光个改动',
'recentchangestext' => '登该个页面浪跟踪最近对维基百科个改动。',
'rcnote'            => '下底是来拉上个 <strong>{{PLURAL:$2|1|$2}}</strong> 日里向个（该歇辰光：$3）最近 <strong>{{PLURAL:$1|1|$1}}</strong> 趟改动。',
'rclistfrom'        => '显示 $1 以来个新改动',
'rcshowhideminor'   => '$1小改动',
'rcshowhidebots'    => '$1机器人',
'rcshowhideliu'     => '$1登录个用户',
'rcshowhideanons'   => '$1匿名用户',
'rcshowhidemine'    => '$1我个改动',
'rclinks'           => '显示来拉上个 $2 日里向个最近 $1 趟改动<br />$3',
'diff'              => '两样',
'hist'              => '历史',
'hide'              => '囥脱',
'show'              => '显示',
'minoreditletter'   => '小',
'newpageletter'     => '新',
'boteditletter'     => '机',
'newsectionsummary' => '/* $1 */ 新段落',

# Recent changes linked
'recentchangeslinked' => '搭界个改动',

# Upload
'upload'            => '上载文物',
'uploadbtn'         => '上载文件',
'reupload'          => '重新上载',
'uploadnologin'     => '朆登录',
'uploadnologintext' => '倷板定要[[Special:UserLogin|登录]]仔再好上载文件。',
'uploaderror'       => '上载出错',
'uploadtext'        => "拿下头只表格来上载文件。要查看或者搜寻之前上载个图片个说法，请到[[Special:ImageList|已上载文件列表]]，上载搭仔删脱也记录勒拉[[Special:Log/upload|上载日志]]里向。

要勒拉页面里向摆进图片个说法，用下头该种形式个链接
'''<nowiki>[[{{ns:image}}:文件.jpg]]</nowiki>'''，
'''<nowiki>[[{{ns:image}}:文件.png|替代文本]]</nowiki>''' 或者用
'''<nowiki>[[{{ns:media}}:文件.ogg]]</nowiki>''' 直接链到文件。",
'uploadlog'         => '文件上载日志',
'uploadlogpage'     => '文件上载日志',
'uploadlogpagetext' => '下底是最近上载文件列表。',
'filename'          => '文件名',
'filedesc'          => '小结',
'fileuploadsummary' => '小结:',
'filestatus'        => '版权状态:',
'filesource'        => '来源:',
'uploadedfiles'     => '已经上载个文件',
'ignorewarning'     => '弗管警告，随便哪亨要保存文件。',
'successfulupload'  => '上载成功哉',
'uploadwarning'     => '上载警告',
'savefile'          => '保存文件',
'uploadedimage'     => '上载 "[[$1]]"',
'sourcefilename'    => '源文件:',
'destfilename'      => '目标文件名:',
'watchthisupload'   => '监控该只页面',

# Special:ImageList
'imagelist_search_for'  => '寻图片名字:',
'imgfile'               => '源文件',
'imagelist'             => '文件列表',
'imagelist_date'        => '日脚',
'imagelist_name'        => '名字',
'imagelist_user'        => '用户',
'imagelist_size'        => '尺寸 (bytes)',
'imagelist_description' => '描述',

# Image description page
'filehist'                  => '文物历史',
'filehist-deleteall'        => '全删',
'filehist-deleteone'        => '删',
'filehist-revert'           => '恢复',
'filehist-user'             => '用户',
'imagelinks'                => '链接',
'nolinkstoimage'            => '呒拨页面链接到该只文件。',
'shareduploadwiki-linktext' => '文件描述页面',
'noimage'                   => '呒拨叫该个名字个文件，倷可以$1。',
'noimage-linktext'          => '上载俚',
'uploadnewversion-linktext' => '上载该文件个新版',

# File reversion
'filerevert'        => '恢复$1',
'filerevert-legend' => '恢复文物',
'filerevert-submit' => '恢复',

# File deletion
'filedelete'        => '删除$1',
'filedelete-legend' => '删除文物',
'filedelete-submit' => '删除',

# MIME search
'download' => '下载',

# List redirects
'listredirects' => '重定向列表',

# Random page
'randompage' => '随便望望',

# Statistics
'statistics'    => '统计',
'sitestats'     => '{{SITENAME}}统计',
'userstats'     => '用户资料',
'sitestatstext' => "数据库里向亨白浪当有'''{{PLURAL:$1|一|$1}}'''只页面。 个包括'''讲张页'''，'''{{SITENAME}}'''个说明页，顶少个'''stub'''页，重定向页搭仔别个作兴还弗好算合格内容页面个页面。 弗包括该星个说话，有'''{{PLURAL:$2|一|$2}}'''只作兴是合格个内容页。 亨白浪当上载着 '''$8''' 只文件。",
'userstatstext' => "亨白浪当有 '''{{PLURAL:$1|1|$1}}''' 个登记户头，搿里向 '''$2''' (或 '''$4%''') 个是 $5。",

'brokenredirects'        => '坏脱个重定向',
'brokenredirectstext'    => '下底个重定向链到弗存在个页面:',
'brokenredirects-edit'   => '（编辑）',
'brokenredirects-delete' => '（删除）',

# Miscellaneous special pages
'unusedimages'         => '弗勒浪使用个文件',
'popularpages'         => '热门页面',
'mostlinked'           => '链进去顶多个页面',
'mostlinkedcategories' => '链进去顶多个分类',
'mostcategories'       => '分类顶多个页面',
'mostimages'           => '链进去顶多个图片',
'mostrevisions'        => '修订过顶顶多趟数个页面',
'shortpages'           => '短页面',
'longpages'            => '长页面',
'protectedpages'       => '已保护页面',
'protectedtitles'      => '已保护个标题',
'listusers'            => '用户列表',
'newpages'             => '新页面',
'newpages-username'    => '用户名:',
'ancientpages'         => '顶顶老个页面',
'move'                 => '捅荡',
'movethispage'         => '捅该只页面',

# Book sources
'booksources-go' => '转到',

# Special:Log
'specialloguserlabel'  => '用户:',
'speciallogtitlelabel' => '标题:',
'log'                  => '记录',

# Special:AllPages
'allpages'          => '全部页面',
'alphaindexline'    => '$1到$2',
'nextpage'          => '下页 ($1)',
'prevpage'          => '上一页（$1）',
'allpagesfrom'      => '显示个页面开始于:',
'allarticles'       => '所有页面',
'allinnamespace'    => '所有页面 ($1 名字空间)',
'allnotinnamespace' => '全部页面 (弗勒 $1 名字空间里向)',
'allpagesprev'      => '前头',
'allpagesnext'      => '下底',
'allpagesprefix'    => '显示个页面有下底个前缀:',
'allpages-bad-ns'   => '{{SITENAME}}没有叫做"$1"个名字空间.',

# Special:Categories
'categories' => '页面分类',

# Special:ListUsers
'listusers-submit' => '显示',

# E-mail user
'emailuser'     => '发E-mail拨该个用户',
'emailfrom'     => '从',
'emailto'       => '发拨',
'emailsubject'  => '主题',
'emailmessage'  => '信息',
'emailsend'     => '发罢',
'emailsent'     => '电子邮件发出去哉',
'emailsenttext' => '倷个电子邮件讯息已经拨发送哉。',

# Watchlist
'watchlist'            => '监控列表',
'mywatchlist'          => '我个监控列表',
'watchlistfor'         => "（'''$1'''个监控列表）",
'nowatchlist'          => '倷个监控列表是空个。',
'watchnologin'         => '朆登录',
'addedwatch'           => '加到监控列表哉',
'addedwatchtext'       => "该个页面 \"[[:\$1]]\" 已经加到侬个[[Special:Watchlist|监控列表]]哉。
将来对该页面个改动搭仔搭界个讲张页个改动会列表垃该面，并且页面会垃拉[[Special:RecentChanges|近段辰光个改变列表]]里向显示成功'''黑体'''，实梗好外加便当拿渠拣出来。假使侬歇仔两日又想拿箇个页面登侬个监控列表里向拿脱个说法，垃侧条里向点击“弗要监控。",
'removedwatch'         => '登监控列表里向拿脱哉',
'removedwatchtext'     => '"[[:$1]]"已经从侬个监控列表移除。',
'watch'                => '监控',
'watchthispage'        => '监控该只页面',
'unwatch'              => '覅监控',
'unwatchthispage'      => '停止监控',
'watchlistcontains'    => '倷个监控列表包括{{PLURAL:$1|1|$1}}只页面。',
'wlshowlast'           => '显示上个 $1 个钟头 $2 日 $3',
'watchlist-show-bots'  => '显示机器人个编辑',
'watchlist-hide-bots'  => '隐藏机器人个编辑',
'watchlist-show-own'   => '显示我个编辑',
'watchlist-hide-own'   => '隐藏我个编辑',
'watchlist-show-minor' => '显示小编辑',
'watchlist-hide-minor' => '隐藏小编辑',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => '监控……',
'unwatching' => '解除监控……',

'enotif_newpagetext' => '该个是一只新页面。',
'changed'            => '改变哉',
'created'            => '建立哉',

# Delete/protect/revert
'deletepage'      => '删脱页面',
'confirm'         => '确认',
'historywarning'  => '警告：倷要删脱个该只页面有历史：',
'actioncomplete'  => '操作完成哉',
'deletedarticle'  => '"[[$1]]" 已经删脱哉',
'dellogpage'      => '删除记录',
'deletionlog'     => '删除记录',
'deletecomment'   => '删脱俚个理由',
'rollback'        => '恢复编辑',
'rollback_short'  => '恢复',
'rollbacklink'    => '恢复',
'rollbackfailed'  => '恢复失败',
'revertpage'      => '恢复[[Special:Contributions/$2|$2]] ([[User talk:$2|讲张]])个改动；恢复到[[User:$1|$1]]个上一版本', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
'protectlogpage'  => '保护日志',
'protectcomment'  => '保护理由:',
'protect-default' => '(默认)',

# Restrictions (nouns)
'restriction-edit' => '编辑',
'restriction-move' => '捅荡',

# Undelete
'undeletepage'    => '查看搭仔恢复删脱个页面',
'viewdeletedpage' => '望望删脱个页面',

# Namespace form on various pages
'namespace'      => '名字空间:',
'invert'         => '反选择',
'blanknamespace' => '（主）',

# Contributions
'contributions' => '用户贡献',
'mycontris'     => '我个贡献',
'contribsub2'   => '$1个贡献（$2）',
'uctop'         => '(顶浪)',

'sp-contributions-blocklog' => '查封记录',
'sp-contributions-username' => 'IP地址或用户名：',

# What links here
'whatlinkshere' => '链进来点啥',
'nolinkshere'   => "呒拨页面链接到 '''[[:$1]]'''。",
'isredirect'    => '重定向页面',

# Block/unblock
'blockip'            => '查封用户',
'ipaddress'          => 'IP 地址:',
'ipadressorusername' => 'IP地址或用户名：',
'ipbreason'          => '理由:',
'ipbreasonotherlist' => '其它原因',
'ipbsubmit'          => '封杀该个用户',
'ipbother'           => '其它时间：',
'badipaddress'       => '无效 IP 地址',
'infiniteblock'      => '永远',
'blocklink'          => '封禁',
'contribslink'       => '贡献',
'blocklogpage'       => '封禁日志',
'blocklogtext'       => '该个是用户封禁搭仔解禁操作个记录。自动封禁个IP地址弗会列勒该答。到[[Special:IPBlockList|IP 封禁列表]]去看当前生效个封禁列表。',
'proxyblocksuccess'  => '好哉。',

# Move page
'move-page-legend'        => '页面捅荡',
'movepagetext'            => "下底只表格会重新命名一只页面，拿俚所有个历史也侪捅到新名字下头。
旧个名字会变成到新名字个重定向页面。
到旧页面个连接弗会改变；注意检查双重定向或者坏脱个重定向。
倷有实概个责任，即连接原要连到俚笃应该连到个场呵去。

注意，如果新名字归面搭已经有页面个说话，老名字个页面'''弗'''会拨移动，除非归个是只空页面或者是只重定向并且呒拨编辑历史。个也就是讲，假使倷犯错误个说话，倷好拿一只重命名过个页面还原到原来个名字，但倷弗好覆盖一只已经来浪个页面。

<b>警告！</b>
个作兴会引起对一只热门页面剧烈个、想弗着个改变。
来操作前头请倷确定倷已经充分了解个能做法个后果。",
'movearticle'             => '页面捅荡:',
'newtitle'                => '新个题目:',
'movepagebtn'             => '页面捅荡',
'pagemovedsub'            => '捅荡成功哉',
'articleexists'           => '叫该个名字个页面已经勒浪哉，要么倷拣个名字是无效个。请重新拣个名字。',
'movedto'                 => '捅到',
'movetalk'                => '捅搭界个讲张页面',
'1movedto2'               => '[[$1]]捅到[[$2]]',
'1movedto2_redir'         => '[[$1]]通过重定向捅到[[$2]]',
'movelogpage'             => '捅荡记录',
'movelogpagetext'         => '下底是拨拉捅荡个页面列表。',
'movereason'              => '理由:',
'revertmove'              => '恢复该捅荡',
'delete_and_move'         => '删脱搭仔捅荡',
'delete_and_move_confirm' => '对哉，删脱该只页面',

# Namespace 8 related
'allmessages'               => '系统讯息',
'allmessagesname'           => '名字',
'allmessagesdefault'        => '默认文本',
'allmessagescurrent'        => '当前文本',
'allmessagestext'           => '该个是MediaWiki名字空间里可用个系统音讯列表。',
'allmessagesnotsupportedDB' => "'''{{ns:special}}:Allmessages''' 呒处显示，因为 '''\$wgUseDatabaseMessages''' 关勒浪。",
'allmessagesfilter'         => '音讯名字过滤:',
'allmessagesmodified'       => '只显示修订过个',

# Thumbnails
'thumbnail-more' => '放大',
'filemissing'    => '文件寻弗着哉',

# Tooltip help for the actions
'tooltip-pt-userpage'        => '我个用户页',
'tooltip-pt-mytalk'          => '我个讲张',
'tooltip-pt-preferences'     => '我个所欢喜',
'tooltip-pt-mycontris'       => '我个贡献列表',
'tooltip-pt-login'           => '鼓励大家登录，必过倒也弗是必须个。',
'tooltip-pt-anonlogin'       => '鼓励登录，必过倒也弗是必须个。',
'tooltip-pt-logout'          => '登出',
'tooltip-ca-talk'            => '讨论内容页',
'tooltip-ca-edit'            => '该篇文章倷可以编辑。请勒拉保存前头先预览。',
'tooltip-ca-addsection'      => '加个评论到搿个讨论里向',
'tooltip-ca-viewsource'      => '该只页面拨保护勒浪，必过倷可以查看源码。',
'tooltip-ca-history'         => '该只页面老早个版本。',
'tooltip-ca-protect'         => '保护该只页面',
'tooltip-ca-delete'          => '删脱该只页面',
'tooltip-ca-move'            => '移动该只页面',
'tooltip-search'             => '搜寻{{SITENAME}}',
'tooltip-p-logo'             => '封面',
'tooltip-n-mainpage'         => '进入封面',
'tooltip-n-portal'           => '关于本计划，可以做什么，应该如何做',
'tooltip-n-recentchanges'    => '列出近段辰光个改动',
'tooltip-n-help'             => '寻求帮助',
'tooltip-t-whatlinkshere'    => '列出所有与此页相链个页面',
'tooltip-t-emailuser'        => '发封信拨该个用户',
'tooltip-t-upload'           => '上传文件',
'tooltip-t-specialpages'     => '亨白浪当个特殊页面列表',
'tooltip-ca-nstab-main'      => '查看内容页',
'tooltip-ca-nstab-user'      => '查看用户页',
'tooltip-ca-nstab-media'     => '查看媒体页',
'tooltip-ca-nstab-special'   => '该个是只特殊页面，倷弗好编辑俚',
'tooltip-ca-nstab-project'   => '查看项目页',
'tooltip-ca-nstab-image'     => '查看图片页',
'tooltip-ca-nstab-mediawiki' => '查看系统讯息',
'tooltip-ca-nstab-template'  => '查看模板',
'tooltip-ca-nstab-help'      => '查看帮忙页面',
'tooltip-ca-nstab-category'  => '查看分类页面',
'tooltip-minoredit'          => '拿该趟编辑标记成小改动',
'tooltip-save'               => '保存倷个改变',
'tooltip-preview'            => '预览倷个改变，请倷勒拉保存前头用用俚!',
'tooltip-diff'               => '显示倷对文章所作个改变',
'tooltip-watch'              => '拿搿只页面加到倷监控列表里向去',

# Attribution
'anonymous' => '{{SITENAME}}浪个匿名用户',

# Patrol log
'patrol-log-auto' => '（自动）',

# Image deletion
'deletedrevision' => '拨删脱个旧修订 $1',

# Special:NewImages
'newimages'    => '新文件陈列室',
'showhidebots' => '（$1机器人）',
'ilsubmit'     => '搜寻',

/*
Short names for language variants used for language conversion links.
To disable showing a particular link, set it to 'disable', e.g.
'variantname-zh-sg' => 'disable',
Variants for Chinese language
*/
'variantname-zh-tw' => '台湾',

# EXIF tags
'exif-artist' => '作者',

'exif-componentsconfiguration-0' => '弗存在',

'exif-subjectdistance-value' => '$1米',

'exif-contrast-2' => '高',

# Pseudotags used for GPSSpeedRef and GPSDestDistanceRef
'exif-gpsspeed-k' => '公里每小时',
'exif-gpsspeed-m' => '英里每小时',

# External editor support
'edit-externally' => '用外部应用程序来编辑该只文件',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => '全部',
'imagelistall'     => '所有',
'watchlistall2'    => '全部',
'namespacesall'    => '全部',
'monthsall'        => '全',

# E-mail address confirmation
'confirmemail'          => '确认电子邮件地址',
'confirmemail_text'     => '该只wiki要求倷来拉用电子邮件服务之前验证电子邮件地址个有效性。揿底下只揿钮来发封确认信到倷电子邮箱。个封信里会有加密个链接。登倷个浏览器里向打开该只链接，确认倷个电子邮箱地址是有效个。',
'confirmemail_send'     => '发送确认码',
'confirmemail_sent'     => '确认电子邮件发出去哉。',
'confirmemail_success'  => '倷个电子邮箱地址已经通过确认哉。乃么倷好登录，享受倪维基百科哉。',
'confirmemail_loggedin' => '倷个电子邮件地址已经拨确认哉。',
'confirmemail_subject'  => '{{SITENAME}}电子邮件地址确认',

# Scary transclusion
'scarytranscludetoolong' => '[对呒起，URL太长了]',

# Delete conflict
'confirmrecreate' => "用户[[User:$1|$1]] ([[User talk:$1|讲张]])勒拉倷开始编辑该页面之后拿俚删脱，理由是： : ''$2'' 请拿定章程，倷阿是真个要重建该页面。",

# action=purge
'confirm_purge_button' => '确定',

# AJAX search
'searchcontaining' => "搜寻里向有 ''$1'' 个页面。",
'articletitles'    => "以 ''$1'' 开头个页面",
'hideresults'      => '囥脱结果',

# Multipage image navigation
'imgmultipageprev' => '← 上一页',
'imgmultipagenext' => '下一页 →',

# Table pager
'ascending_abbrev'  => '升序',
'descending_abbrev' => '降序',
'table_pager_next'  => '下页',
'table_pager_prev'  => '上页',
'table_pager_first' => '头一页',
'table_pager_last'  => '压末一页',
'table_pager_limit' => '显示 $1 条每页',

# Auto-summaries
'autoredircomment' => '重定向到 [[$1]]',
'autosumm-new'     => '新页面：$1',

# Watchlist editor
'watchlistedit-normal-title' => '编辑监控列表',

# Special:Version
'version' => '版本', # Not used as normal message but as header for the special page itself

# Special:FilePath
'filepath'        => '文件路径',
'filepath-page'   => '文件：',
'filepath-submit' => '路径',

# Special:SpecialPages
'specialpages' => '特殊页面',

);
